==> apache-pinot-0.12.1-src.tar.gz: apache-pinot-0.12.1-src/pinot-spi/src/main/java/org/apache/pinot/spi/config/table/ingestion/StreamIngestionConfig.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.spi.config.table.ingestion;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.util.List;
import java.util.Map;
import org.apache.pinot.spi.config.BaseJsonConfig;


/**
 * Contains all the configs related to the streams for ingestion
 */
public class StreamIngestionConfig extends BaseJsonConfig {

  @JsonPropertyDescription("All configs for the streams from which to ingest")
  private final List<Map<String, String>> _streamConfigMaps;

  @JsonCreator
  public StreamIngestionConfig(@JsonProperty("streamConfigMaps") List<Map<String, String>> streamConfigMaps) {
    _streamConfigMaps = streamConfigMaps;
  }

  public List<Map<String, String>> getStreamConfigMaps() {
    return _streamConfigMaps;
  }
}

==> apache-pinot-1.1.0-src.tar.gz: apache-pinot-1.1.0-src/pinot-spi/src/main/java/org/apache/pinot/spi/config/table/ingestion/StreamIngestionConfig.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pinot.spi.config.table.ingestion;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.util.List;
import java.util.Map;
import org.apache.pinot.spi.config.BaseJsonConfig;


/**
 * Contains all the configs related to the streams for ingestion
 */
public class StreamIngestionConfig extends BaseJsonConfig {

  @JsonPropertyDescription("All configs for the streams from which to ingest")
  private final List<Map<String, String>> _streamConfigMaps;

  @JsonPropertyDescription("Whether to use column major mode when creating the segment.")
  private boolean _columnMajorSegmentBuilderEnabled;

  @JsonCreator
  public StreamIngestionConfig(@JsonProperty("streamConfigMaps") List<Map<String, String>> streamConfigMaps) {
    _streamConfigMaps = streamConfigMaps;
  }

  public List<Map<String, String>> getStreamConfigMaps() {
    return _streamConfigMaps;
  }

  public void setColumnMajorSegmentBuilderEnabled(boolean enableColumnMajorSegmentCreation) {
    _columnMajorSegmentBuilderEnabled = enableColumnMajorSegmentCreation;
  }

  public boolean getColumnMajorSegmentBuilderEnabled() {
    return _columnMajorSegmentBuilderEnabled;
  }
}
